
# Slot: has biomarker


holds between a disease or phenotypic feature and a measurable molecular entity that is used as an indicator of the presence or state of the disease or feature.

URI: [biolink:has_biomarker](https://w3id.org/biolink/vocab/has_biomarker)

## Domain and Range

[DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md) ->  <sub>0..*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [correlated with](correlated_with.md)

## Children


## Used by

 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
